@@ -41,12 +41,6 @@
             deleteButtonHandler(inline.find("a." + options.deleteCssClass), options);
         });
     };
-
-    getFormIndex = function(elem, options, regex) {
-        var formIndex = elem.find("[id^='id_" + options.prefix + "']").attr('id');
-        if (!formIndex) { return -1; }
-        return parseInt(regex.exec(formIndex)[1], 10);
-    }
     
     updateFormIndex = function(elem, options, replace_regex, replace_with) {
         elem.find(':input,span,table,iframe,label,a,ul,p,img,div').each(function() {
@@ -76,7 +70,7 @@
             }
             // add options.predeleteCssClass to forms with the delete checkbox checked
             form.find("li.grp-delete-handler-container input").each(function() {
-                if ($(this).attr("checked") && form.hasClass("has_original")) {
+                if ($(this).is(":checked") && form.hasClass("has_original")) {
                     form.toggleClass(options.predeleteCssClass);
                 }
             });
@@ -134,26 +128,24 @@
             var inline = elem.parents(".grp-group"),
                 form = $(this).parents("." + options.formCssClass).first(),
                 totalForms = inline.find("#id_" + options.prefix + "-TOTAL_FORMS"),
-                maxForms = inline.find("#id_" + options.prefix + "-MAX_NUM_FORMS"),
-                re = /-(\d+)-/,
-                removedFormIndex = getFormIndex(form, options, re);
+                maxForms = inline.find("#id_" + options.prefix + "-MAX_NUM_FORMS");
             // callback
             options.onBeforeRemoved(form);
             // remove form
             form.remove();
             // update total forms
-            totalForms.val(parseInt(totalForms.val(), 10) - 1);
+            var index = parseInt(totalForms.val(), 10);
+            totalForms.val(index - 1);
             // show add button in case we've dropped below max
             if ((maxForms.val() !== 0) && (maxForms.val() - totalForms.val()) > 0) {
                 showAddButtons(inline, options);
             }
-            // update form index (only forms with a higher index than the removed form)
+            // update form index (for all forms)
+            var re = /-\d+-/g,
+                i = 0;
             inline.find("." + options.formCssClass).each(function() {
-                var form = $(this),
-                    formIndex = getFormIndex(form, options, re);
-                if (formIndex > removedFormIndex) {
-                    updateFormIndex(form, options, re, "-" + (formIndex - 1) + "-");
-                }
+                updateFormIndex($(this), options, re, "-" + i + "-");
+                i++;
             });
             // callback
             options.onAfterRemoved(inline);
@@ -169,10 +161,10 @@
             // toggle options.predeleteCssClass and toggle checkbox
             if (form.hasClass("has_original")) {
                 form.toggleClass(options.predeleteCssClass);
-                if (deleteInput.attr("checked")) {
+                if (deleteInput.prop("checked")) {
                     deleteInput.removeAttr("checked");
                 } else {
-                    deleteInput.attr("checked", 'checked');
+                    deleteInput.prop("checked", true);
                 }
             }
             // callback
