@@ -30,6 +30,9 @@ def get_label(f):
         return f.related_label()
     return smart_text(f)
 
+def import_from(module, name):
+    module = __import__(module, fromlist=[name])
+    return getattr(module, name)
 
 def ajax_response(data):
     return HttpResponse(json.dumps(data), content_type='application/javascript')
@@ -49,8 +52,21 @@ class RelatedLookup(View):
         self.model = models.get_model(self.GET['app_label'], self.GET['model_name'])
         return self.model
 
+    def get_filtered_queryset(self, qs):
+        filters = {}
+        query_string = self.GET.get('query_string', None)
+
+        if query_string:
+            for item in query_string.split(":"):
+                k, v = item.split("=")
+                if k != "t":
+                    filters[smart_bytes(k)] = prepare_lookup_value(smart_bytes(k), smart_bytes(v))
+        return qs.filter(**filters)
+
     def get_queryset(self):
-        return self.model._default_manager.all()
+        qs = self.model._default_manager.get_queryset()
+        qs = self.get_filtered_queryset(qs)
+        return qs
 
     def get_data(self):
         obj_id = self.GET['object_id']
@@ -99,17 +115,6 @@ class AutocompleteLookup(RelatedLookup):
     def request_is_valid(self):
         return 'term' in self.GET and 'app_label' in self.GET and 'model_name' in self.GET
 
-    def get_filtered_queryset(self, qs):
-        filters = {}
-        query_string = self.GET.get('query_string', None)
-
-        if query_string:
-            for item in query_string.split("&"):
-                k, v = item.split("=")
-                if k != "t":
-                    filters[smart_bytes(k)] = prepare_lookup_value(smart_bytes(k), smart_bytes(v))
-        return qs.filter(**filters)
-
     def get_searched_queryset(self, qs):
         model = self.model
         term = self.GET["term"]
@@ -122,20 +127,16 @@ class AutocompleteLookup(RelatedLookup):
         try:
             search_fields = model.autocomplete_search_fields()
         except AttributeError:
-            try:
-                search_fields = AUTOCOMPLETE_SEARCH_FIELDS[model._meta.app_label][model._meta.module_name]
-            except KeyError:
-                search_fields = ()
+            search_fields = AUTOCOMPLETE_SEARCH_FIELDS[model._meta.app_label][model._meta.module_name]
+        except KeyError:
+            search_fields = ()
 
-        if search_fields:
-            for word in term.split():
-                search = [models.Q(**{smart_text(item): smart_text(word)}) for item in search_fields]
-                search_qs = QuerySet(model)
-                search_qs.query.select_related = qs.query.select_related
-                search_qs = search_qs.filter(reduce(operator.or_, search))
-                qs &= search_qs
-        else:
-            qs = model.objects.none()
+        for word in term.split():
+            search = [models.Q(**{smart_bytes(item): smart_bytes(word)}) for item in search_fields]
+            search_qs = QuerySet(model)
+            search_qs.query.select_related = qs.query.select_related
+            search_qs = search_qs.filter(reduce(operator.or_, search))
+            qs &= search_qs
         return qs
 
     def get_queryset(self):
